CCL: /home/chisarie/Documents/lsst_ccl/CCL/tests/ccl_test_distances.c File Reference

CCL

Macros | Functions
ccl_test_distances.c File Reference
`#include "ccl.h"`
`#include "ctest.h"`
`#include <stdio.h>`
`#include <math.h>`

## Macros
#define | DISTANCES_TOLERANCE 1.0e-4

## Functions
| CTEST_DATA (distances)
| CTEST_SETUP (distances)
| CTEST2 (distances, model_1)
| CTEST2 (distances, model_2)
| CTEST2 (distances, model_3)
| CTEST2 (distances, model_4)
| CTEST2 (distances, model_5)

## Macro Definition Documentation

## ◆ DISTANCES_TOLERANCE

#define DISTANCES_TOLERANCE 1.0e-4

## Function Documentation

## ◆ CTEST2() [1/5]

CTEST2 | ( | distances | ,
|  | model_1 |
| ) |  |

## ◆ CTEST2() [2/5]

CTEST2 | ( | distances | ,
|  | model_2 |
| ) |  |

## ◆ CTEST2() [3/5]

CTEST2 | ( | distances | ,
|  | model_3 |
| ) |  |

## ◆ CTEST2() [4/5]

CTEST2 | ( | distances | ,
|  | model_4 |
| ) |  |

## ◆ CTEST2() [5/5]

CTEST2 | ( | distances | ,
|  | model_5 |
| ) |  |

## ◆ CTEST_DATA()

CTEST_DATA | ( | distances |  | ) |

## ◆ CTEST_SETUP()

CTEST_SETUP | ( | distances |  | ) |